@@ -27,9 +27,7 @@ public slots:
     void onError(const QString &message);
     void showProgressDialog(const QString &message, int numberOfOperations);
     void updateProgressDialog(int progress);
-#ifndef QML_USER_INTERFACE
     void cancelProgressDialog();
-#endif
 
 signals:
     void alert(const QString &message);
@@ -37,9 +35,11 @@ signals:
     void error(const QString &message);
     void busy(const QString &message, int numberOfOperations);
     void busyProgressChanged(int progress);
+    void canceled();
 
-#ifndef QML_USER_INTERFACE
 private:
+    static Notifications *self;
+#ifndef QML_USER_INTERFACE
     QProgressDialog *m_progressDialog;
 #endif
 };
