@@ -1,25 +1,22 @@
 #include "searchlistmodel.h"
+#include "settings.h"
 #include <QStringListModel>
 #include <QStringList>
-#include <QSettings>
 
 SearchListModel::SearchListModel(QObject *parent) :
     QSortFilterProxyModel(parent),
-    m_model(new QStringListModel(this)),
-    m_settings(new QSettings("cuteTube", "cuteTube", this))
+    m_model(new QStringListModel(this))
   #if (defined (QML_USER_INTERFACE) && (!defined (Q_WS_MAEMO_5)))
-    ,m_highlight(m_settings->value("Appearance/activeColor", QString("#0881cb")).toString())
+    ,m_highlight(Settings::instance()->activeColor())
   #endif
 {
     this->setSourceModel(m_model);
     this->setFilterRole(Qt::DisplayRole);
     this->setDynamicSortFilter(true);
-    this->setSearches(m_settings->value("Search/recentSearches", QStringList()).toStringList());
+    this->setSearches(Settings::instance()->value("Search/recentSearches", QStringList()).toStringList());
 }
 
-SearchListModel::~SearchListModel() {
-    this->saveSearches();
-}
+SearchListModel::~SearchListModel() {}
 
 void SearchListModel::saveSearches() {
     QStringList strings;
@@ -30,7 +27,7 @@ void SearchListModel::saveSearches() {
         i++;
     }
 
-    m_settings->setValue("Search/recentSearches", strings);
+    Settings::instance()->setValue("Search/recentSearches", strings);
 }
 
 void SearchListModel::setSearches(const QStringList &searches) {
@@ -69,11 +66,13 @@ void SearchListModel::addSearch(const QString &query) {
 
     m_model->insertRow(0);
     m_model->setData(m_model->index(0), query, 0);
+    this->saveSearches();
     emit countChanged(this->rowCount());
 }
 
 void SearchListModel::removeSearch(int row) {
     m_model->removeRow(row);
+    this->saveSearches();
     emit countChanged(this->rowCount());
 }
 
@@ -81,6 +80,7 @@ void SearchListModel::clearSearches() {
     this->beginResetModel();
     m_model->setStringList(QStringList());
     this->endResetModel();
+    this->saveSearches();
     emit countChanged(this->rowCount());
     emit alert(tr("Search history cleared"));
 }
