@@ -1,4 +1,5 @@
 #include "selectionmodels.h"
+#include "definitions.h"
 #include <qplatformdefs.h>
 #include <QFileInfo>
 
@@ -19,6 +20,18 @@ QHash<int, QByteArray> SelectionModel::roleNames() const {
 }
 #endif
 
+void SelectionModel::addItem(const QString &name, const QVariant &value) {
+    QStandardItem *item = new QStandardItem(name);
+    item->setData(value);
+    item->setTextAlignment(this->textAlignment());
+    item->setEditable(false);
+    this->appendRow(item);
+}
+
+bool SelectionModel::removeItem(int row) {
+    return this->removeRow(row);
+}
+
 QString SelectionModel::name(int row) const {
     return this->data(this->index(row, 0), Qt::DisplayRole).toString();
 }
@@ -35,14 +48,6 @@ QVariantMap SelectionModel::get(int row) const {
     return item;
 }
 
-void SelectionModel::addItem(const QString &name, const QVariant &value) {
-    QStandardItem *item = new QStandardItem(name);
-    item->setData(value);
-    item->setTextAlignment(this->textAlignment());
-    item->setEditable(false);
-    this->appendRow(item);
-}
-
 SearchOrderModel::SearchOrderModel(QObject *parent) :
     SelectionModel(parent)
 {
@@ -487,9 +492,19 @@ TransferPriorityModel::TransferPriorityModel(QObject *parent) :
 ConcurrentTransfersModel::ConcurrentTransfersModel(QObject *parent) :
     SelectionModel(parent)
 {
-    this->addItem(tr("1"), 1);
-    this->addItem(tr("2"), 2);
-    this->addItem(tr("3"), 3);
+    for (int i = 1; i <= MAX_CONCURRENT_TRANSFERS; i++) {
+        this->addItem(QString::number(i), i);
+    }
+
+    emit countChanged(this->rowCount());
+}
+
+ConnectionsModel::ConnectionsModel(QObject *parent) :
+    SelectionModel(parent)
+{
+    for (int i = 1; i <= MAX_CONNECTIONS; i++) {
+        this->addItem(QString::number(i), i);
+    }
 
     emit countChanged(this->rowCount());
 }
