@@ -4,6 +4,7 @@
 #include <QObject>
 #include <QQueue>
 #include <QImage>
+#include <QCache>
 
 class Thumbnail;
 class QNetworkReply;
@@ -35,6 +36,10 @@ signals:
     void downloadThumbnail(const QUrl &url);
 
 private:
+    static ThumbnailCache *self;
+    static QThread *cacheThread;
+    static QCache<QUrl, Thumbnail> thumbnails;
+
     QQueue<QUrl> m_urls;
 };
 
