@@ -19,7 +19,7 @@ void ThumbnailDownloader::downloadThumbnail(const QUrl &url) {
 }
 
 void ThumbnailDownloader::onThumbnailDownloaded() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         return;
