@@ -75,6 +75,10 @@ class VideoItem : public QObject
     Q_PROPERTY(QUrl largeThumbnailUrl
                READ largeThumbnailUrl
                NOTIFY largeThumbnailUrlChanged)
+    Q_PROPERTY(QUrl subtitlesUrl
+               READ subtitlesUrl
+               WRITE setSubtitlesUrl
+               NOTIFY subtitlesUrlChanged)
     Q_PROPERTY(bool liked
                READ liked
                NOTIFY likedChanged)
@@ -145,6 +149,8 @@ public:
     inline void setThumbnailUrl(const QUrl &url) { m_thumbUrl = url; emit thumbnailUrlChanged(url); }
     inline QUrl largeThumbnailUrl() const { return m_largeThumbUrl; }
     inline void setLargeThumbnailUrl(const QUrl &url) { m_largeThumbUrl = url; emit largeThumbnailUrlChanged(url); }
+    inline QUrl subtitlesUrl() const { return m_subtitlesUrl; }
+    inline void setSubtitlesUrl(const QUrl &url) { m_subtitlesUrl = url; emit subtitlesUrlChanged(url); }
     inline bool liked() const { return m_liked; }
     inline void setLiked(bool liked) { m_liked = liked; emit likedChanged(liked); }
     inline void like() { this->setLiked(true); this->setLikes(this->likes() + 1); }
@@ -183,6 +189,7 @@ signals:
     void viewCountChanged(int count);
     void thumbnailUrlChanged(const QUrl &url);
     void largeThumbnailUrlChanged(const QUrl &url);
+    void subtitlesUrlChanged(const QUrl &url);
     void likedChanged(bool liked);
     void dislikedChanged(bool disliked);
     void favouriteChanged(bool favourite);
@@ -212,6 +219,7 @@ private:
     int m_viewCount;
     QUrl m_thumbUrl;
     QUrl m_largeThumbUrl;
+    QUrl m_subtitlesUrl;
     bool m_liked;
     bool m_disliked;
     bool m_favourite;
