@@ -1,5 +1,5 @@
 #include "vimeo.h"
-#include "utils.h"
+#include "definitions.h"
 #include "oauth.h"
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
@@ -21,7 +21,7 @@
 
 using namespace QtOAuth;
 
-Vimeo* vimeoInstance = 0;
+Vimeo* Vimeo::self = 0;
 
 const QString CLIENT_ID("b73846eb250c788a08bda2458be6ae9aebfda98e");
 const QString CLIENT_SECRET("6d6a7f4b5f013efe183f12d6e09be31051eb5eed");
@@ -41,8 +41,8 @@ Vimeo::Vimeo(QObject *parent) :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!vimeoInstance) {
-        vimeoInstance = this;
+    if (!self) {
+        self = this;
     }
 
     m_queryOrders[Queries::Relevance] = "relevant";
@@ -56,7 +56,7 @@ Vimeo::~Vimeo() {
 }
 
 Vimeo* Vimeo::instance() {
-    return vimeoInstance;
+    return !self ? new Vimeo : self;
 }
 
 void Vimeo::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -104,7 +104,7 @@ QNetworkReply* Vimeo::createReply(QUrl feed, int offset) {
     qDebug() << feed;
 
     QNetworkRequest request(feed);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", feed, QMap<QString, QString>()));
 
     return this->networkAccessManager()->get(request);
@@ -139,7 +139,7 @@ QNetworkReply* Vimeo::createSearchReply(const QString &query, int offset, int or
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
 
     return this->networkAccessManager()->get(request);
@@ -162,7 +162,7 @@ void Vimeo::getAuthUrl() {
     QMap<QString, QString> params;
     params.insert("oauth_callback", REDIRECT_URI);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, params));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkAuthUrl()));
@@ -226,7 +226,7 @@ void Vimeo::signIn(const QString &displayName, const QUrl &response) {
         params.insert("oauth_token_secret", this->requestSecret());
         params.insert("oauth_verifier", verifier);
         QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
         request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, params));
         QNetworkReply *reply = this->networkAccessManager()->get(request);
         this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -292,7 +292,7 @@ void Vimeo::clearCache() {
 void Vimeo::postRequest(const QUrl &url) {
     qDebug() << url;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply* reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
@@ -341,7 +341,7 @@ void Vimeo::getAlbums(int offset) {
     url.addQueryItem("page", QString::number(offset));
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addAlbums()));
@@ -461,7 +461,7 @@ void Vimeo::getGroups(int offset) {
     url.addQueryItem("page", QString::number(offset));
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addGroups()));
@@ -551,7 +551,7 @@ void Vimeo::getSubscriptions(int offset) {
     url.addQueryItem("page", QString::number(offset));
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addSubscriptions()));
@@ -645,7 +645,7 @@ void Vimeo::getFullVideo(QString id) {
     url.addQueryItem("video_id", id);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideo()));
@@ -714,7 +714,7 @@ void Vimeo::getCurrentUserProfile() {
     url.addQueryItem("method", "people.getInfo");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCurrentUserProfile()));
@@ -777,7 +777,7 @@ void Vimeo::getUserProfile(const QString &id) {
     url.addQueryItem("user_id", id);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkUserProfile()));
@@ -1277,7 +1277,7 @@ void Vimeo::getAlbumForCache() {
 #endif
     QNetworkRequest request(url);
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCacheAlbum()));
 }
@@ -1506,7 +1506,7 @@ void Vimeo::getSubscriptionForCache(const QString &id) {
     url.addQueryItem("user_id", id);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCacheSubscription()));
@@ -1657,7 +1657,7 @@ void Vimeo::getAddedComment(const QString &videoId) {
     url.addQueryItem("per_page", "1");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkAddedComment()));
@@ -1752,7 +1752,7 @@ void Vimeo::getVideoFromId(const QString &id) {
     url.addQueryItem("video_id", id);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkVideoFromId()));
