@@ -3,7 +3,6 @@
 
 #include "stackedwindow.h"
 
-class Session;
 class ArchiveListModel;
 class ListView;
 class FilterBox;
@@ -16,8 +15,11 @@ class QModelIndex;
 class ArchiveWindow : public StackedWindow
 {
     Q_OBJECT
+
 public:
-    explicit ArchiveWindow(Session *session, StackedWindow *parent);
+    explicit ArchiveWindow(StackedWindow *parent);
+
+protected:
     void keyPressEvent(QKeyEvent *event);
     
 private:
