@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Session;
 class WebView;
 class QProgressBar;
 class QGridLayout;
@@ -14,7 +13,7 @@ class DailymotionAuthDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit DailymotionAuthDialog(Session *session, const QString &accountName, QWidget *parent = 0);
+    explicit DailymotionAuthDialog(const QString &accountName, QWidget *parent = 0);
 
 private:
     inline void setLandscapeLayout() { this->setFixedHeight(340); }
@@ -24,7 +23,6 @@ private slots:
     void checkUrlForCode(const QUrl &url);
 
 private:
-    Session *m_session;
     QString m_name;
     WebView *m_webView;
     QProgressBar *m_progressBar;
