@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include <QVariantMap>
 
-class Session;
 class DailymotionUserPlaylistListModel;
 class ListView;
 class QDialogButtonBox;
@@ -18,7 +17,7 @@ class DailymotionPlaylistDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit DailymotionPlaylistDialog(Session *session, QWidget *parent = 0);
+    explicit DailymotionPlaylistDialog(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -34,7 +33,6 @@ signals:
     void addToNewPlaylist(const QVariantMap &playlist);
 
 private:
-    Session *m_session;
     DailymotionUserPlaylistListModel *m_model;
     ListView *m_listView;
     QDialogButtonBox *m_buttonBox;
