@@ -41,7 +41,7 @@ SearchDialog::SearchDialog(QWidget *parent) :
 
     QWidget *scrollWidget = new QWidget(m_scrollArea);
     QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
-
+    vbox->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(m_searchEdit);
 
     if (m_searchServiceSelector) {
@@ -81,10 +81,10 @@ SearchDialog::SearchDialog(QWidget *parent) :
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-    this->connect(m_searchEdit, SIGNAL(returnPressed()), this, SLOT(parseSearchQuery()));
+    this->connect(m_searchEdit, SIGNAL(returnPressed()), this, SLOT(accept()));
     this->connect(m_searchEdit, SIGNAL(textChanged(QString)), this, SLOT(onSearchTextChanged(QString)));
     this->connect(m_historyButton, SIGNAL(clicked()), this, SLOT(showSearchHistory()));
-    this->connect(m_searchButton, SIGNAL(clicked()), this, SLOT(parseSearchQuery()));
+    this->connect(m_searchButton, SIGNAL(clicked()), this, SLOT(accept()));
 
     this->onServiceChanged(Settings::instance()->searchSite());
     this->onSearchTypeChanged(Settings::instance()->searchType());
@@ -174,14 +174,14 @@ void SearchDialog::onSearchTextChanged(const QString &text) {
     }
 }
 
-void SearchDialog::parseSearchQuery() {
-    if ((!ClipboardMonitor::instance()->clipboardUrl().isEmpty()) && (m_searchEdit->text().isEmpty())) {
-        emit goToVideo(ClipboardMonitor::instance()->clipboardUrl());
+void SearchDialog::accept() {
+    if ((ClipboardMonitor::instance()->clipboardUrl().isEmpty()) && (m_searchEdit->text().isEmpty())) {
+        emit search(ClipboardMonitor::instance()->clipboardUrl());
     }
-    else {
+    else if (!m_searchEdit->text().isEmpty()) {
         m_model->addSearch(m_searchEdit->text());
         emit search(m_searchEdit->text());
     }
 
-    this->accept();
+    QDialog::accept();
 }
