@@ -27,10 +27,10 @@ public:
 
 private slots:
     void showSearchHistory();
-    void parseSearchQuery();
     void onServiceChanged(Services::VideoService service);
     void onSearchTypeChanged(Queries::QueryType type);
     void onSearchTextChanged(const QString &text);
+    void accept();
 
 private:
     void setLandscapeLayout();
@@ -38,7 +38,6 @@ private:
 
 signals:
     void search(const QString &query);
-    void goToVideo(const QString &url);
     
 private:
     QLineEdit *m_searchEdit;
