@@ -9,7 +9,8 @@ ThumbnailLabel::ThumbnailLabel(QWidget *parent) :
     QWidget(parent),
     m_duration(0),
     m_interactive(true),
-    m_pressed(false)
+    m_pressed(false),
+    m_allowClick(true)
 {
 }
 
@@ -47,7 +48,12 @@ void ThumbnailLabel::mouseReleaseEvent(QMouseEvent *event) {
         event->accept();
         m_pressed = false;
         this->repaint();
-        emit clicked();
+
+        if (m_allowClick) {
+            emit clicked();
+            m_allowClick = false;
+            this->startTimer(500);
+        }
     }
     else {
         event->ignore();
@@ -96,3 +102,9 @@ void ThumbnailLabel::paintEvent(QPaintEvent *event) {
         painter.drawText(backgroundRect, Qt::AlignCenter, Utils::durationFromSecs(m_duration));
     }
 }
+
+void ThumbnailLabel::timerEvent(QTimerEvent *event) {
+    m_allowClick = true;
+    event->accept();
+    this->killTimer(event->timerId());
+}
