@@ -10,7 +10,7 @@ class VideoPlaybackWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit VideoPlaybackWindow(Session *session, QList< QSharedPointer<VideoItem> > playlist, QWidget *parent = 0);
+    explicit VideoPlaybackWindow(QList< QSharedPointer<VideoItem> > playlist, QWidget *parent = 0);
     ~VideoPlaybackWindow();
 
 protected:
@@ -19,6 +19,7 @@ protected:
 
 private slots:
     void toggleControls();
+    void onStateChanged(QMediaPlayer::State state);
     
 private:
     ScreenOrientation::Orientation m_oldOrientation;
