@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class ListView;
 class YouTubePlaylistListModel;
 class QLabel;
@@ -14,9 +13,10 @@ class QModelIndex;
 class YouTubePlaylistListTab : public AbstractTab
 {
     Q_OBJECT
+
 public:
-    explicit YouTubePlaylistListTab(Session *session, QWidget *parent = 0);
-    void setPlaylistFeed(const QString &feed);
+    explicit YouTubePlaylistListTab(QWidget *parent = 0);
+    void setPlaylistFeed(const QUrl &feed);
 
 private:
     void setLandscapeLayout();
@@ -29,7 +29,6 @@ private slots:
     void showPlaylist(QSharedPointer<PlaylistItem> playlist);
 
 private:
-    Session *m_session;
     ListView *m_listView;
     YouTubePlaylistListModel *m_model;
     QLabel *m_noResultsLabel;
