@@ -4,12 +4,13 @@
 #include "../base/youtubeplaylistlistmodel.h"
 #include "listview.h"
 #include <QLabel>
+#include <QMaemo5Style>
 
 YouTubePlaylistListWindow::YouTubePlaylistListWindow(QWidget *parent) :
     StackedWindow(parent),
     m_listView(new ListView(this)),
     m_model(new YouTubePlaylistListModel(this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No playlists found")), this))
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No playlists found")), this))
 {
     this->setCentralWidget(m_listView);
 
