@@ -3,7 +3,6 @@
 
 #include "abstracttab.h"
 
-class Session;
 class YouTubeSubscriptionListModel;
 class ListView;
 class QMenu;
@@ -15,8 +14,9 @@ class QModelIndex;
 class YouTubeSubscriptionsTab : public AbstractTab
 {
     Q_OBJECT
+
 public:
-    explicit YouTubeSubscriptionsTab(Session *session, QWidget *parent = 0);
+    explicit YouTubeSubscriptionsTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -32,7 +32,6 @@ private slots:
     void showSubscriptionVideos();
     
 private:
-    Session *m_session;
     YouTubeSubscriptionListModel *m_model;
     ListView *m_listView;
     QMenu *m_contextMenu;
